Overview — PyMedPhys

Toggle navigation sidebar
Toggle in-page Table of Contents

# Overview

This document is a work in progress.

## Recommended tools

- Visual Studio Code

## Recommended tutorial

I recommend the `Git and GitHub` portion of the don’t be afraid to commit tutorial. To be able to contribute to `pymedphys` you need to have a handle on git and GitHub and how they interact. I do recommend the whole `Git and GitHub` section however, the key concepts that are required are:

- Give GitHub your ssh keys

- Creating a new branch

- Keeping main clean

- Incorporating upstream changes

- Add an upstream remote